@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
- * SPDX-FileCopyrightText: 2009-2019, Marek Lindner <mareklindner@neomailbox.ch>
+ * SPDX-FileCopyrightText: Marek Lindner <mareklindner@neomailbox.ch>
  */
 
 #ifndef __AP51_FLASH_ROUTER_TYPES_H__
@@ -8,6 +8,7 @@
 #include <stdint.h>
 
 #include "ap51-flash.h"
+#include "list.h"
 #include "compat.h"
 
 struct node;
@@ -26,7 +27,8 @@ struct node;
 struct router_type {
 	char desc[DESC_MAX_LENGTH];
 	void (*detect_pre)(const uint8_t *our_mac);
-	int (*detect_main)(void *priv, const char *packet_buff,
+	int (*detect_main)(const struct router_type *router_type,
+			   void *priv, const char *packet_buff,
 			   int packet_buff_len);
 	void (*detect_post)(struct node *node, const char *packet_buff,
 			    int packet_buff_len);
@@ -35,16 +37,16 @@ struct router_type {
 	int priv_size;
 };
 
-struct mac_whitelist_entry {
+struct mac_allowlist_entry {
+	struct list_head list;
 	uint8_t mac[ETH_ALEN];
-	struct mac_whitelist_entry *next;
 };
 
 int router_types_init(void);
 void router_types_detect_pre(const uint8_t *our_mac);
 int router_types_detect_main(struct node *node, const char *packet_buff,
 			     int packet_buff_len);
-int mac_whitelist_add(const char *macstr);
+int mac_allowlist_add(const char *macstr);
 
 extern int router_types_priv_size;
 
